aboutsummaryrefslogtreecommitdiffstats
path: root/modules/migrations/git.go
diff options
context:
space:
mode:
Diffstat (limited to 'modules/migrations/git.go')
-rw-r--r--modules/migrations/git.go8
1 files changed, 4 insertions, 4 deletions
diff --git a/modules/migrations/git.go b/modules/migrations/git.go
index cbaa372821..335d44ec9b 100644
--- a/modules/migrations/git.go
+++ b/modules/migrations/git.go
@@ -53,9 +53,9 @@ func (g *PlainGitDownloader) GetReleases() ([]*base.Release, error) {
return nil, ErrNotSupported
}
-// GetIssues returns issues according start and limit
-func (g *PlainGitDownloader) GetIssues(start, limit int) ([]*base.Issue, error) {
- return nil, ErrNotSupported
+// GetIssues returns issues according page and perPage
+func (g *PlainGitDownloader) GetIssues(page, perPage int) ([]*base.Issue, bool, error) {
+ return nil, false, ErrNotSupported
}
// GetComments returns comments according issueNumber
@@ -63,7 +63,7 @@ func (g *PlainGitDownloader) GetComments(issueNumber int64) ([]*base.Comment, er
return nil, ErrNotSupported
}
// GetPullRequests returns pull requests according start and limit
func (g *PlainGitDownloader) GetPullRequests(start, limit int) ([]*base.PullRequest, error) {
return nil, ErrNotSupported
}
@@ -63,7 +63,7 @@ func (g *PlainGitDownloader) GetComments(issueNumber int64) ([]*base.Comment, er
return nil, ErrNotSupported
}
-// GetPullRequests returns pull requests according start and limit
+// GetPullRequests returns pull requests according page and perPage
func (g *PlainGitDownloader) GetPullRequests(start, limit int) ([]*base.PullRequest, error) {
return nil, ErrNotSupported